@@ -105,6 +105,14 @@ def is_bfloat16_supported():
     return current_context().device.supports_bfloat16
 
 
+def is_fp8_supported():
+    """Whether FP8 are supported.
+
+    fp8 type and intrinsic functions are supported on devices with compute capability >= 8.9
+    """
+    return current_context().device.supports_fp8
+
+
 @require_context
 def to_device(obj, stream=0, copy=True, to=None):
     """to_device(obj, stream=0, copy=True, to=None)
@@ -538,6 +546,9 @@ def detect():
         if os.name == "nt":
             attrs += [("Compute Mode", "TCC" if tcc else "WDDM")]
         attrs += [("FP32/FP64 Performance Ratio", fp32_to_fp64_ratio)]
+        attrs += [("FP16 Support", "Yes" if dev.supports_float16 else "No")]
+        attrs += [("BF16 Support", "Yes" if dev.supports_bfloat16 else "No")]
+        attrs += [("FP8 Support", "Yes" if dev.supports_fp8 else "No")]
         if cc < (3, 5):
             support = "[NOT SUPPORTED: CC < 3.5]"
         elif cc < (5, 0):
