@@ -31,6 +31,7 @@ from numba.cuda.core.ir_utils import (
     compute_cfg_from_blocks,
     is_operator_or_getitem,
 )
+from numba.cuda.core.callconv import CUDACallConv
 
 from numba.cuda.core import postproc, rewrites, funcdesc, config
 
@@ -325,6 +326,12 @@ class BaseNativeLowering(abc.ABC, LoweringPass):
         metadata = state.metadata
         pre_stats = passmanagers.dump_refprune_stats()
 
+        call_conv = flags.call_conv
+        if call_conv is None:
+            call_conv = CUDACallConv(state.targetctx)
+
+        mangler = call_conv.mangler
+
         msg = "Function %s failed at nopython mode lowering" % (
             state.func_id.func_name,
         )
@@ -336,10 +343,12 @@ class BaseNativeLowering(abc.ABC, LoweringPass):
                     typemap,
                     restype,
                     calltypes,
-                    mangler=targetctx.mangler,
+                    mangler=mangler,
                     inline=flags.forceinline,
                     noalias=flags.noalias,
                     abi_tags=[flags.get_mangle_string()],
+                    call_conv=call_conv,
+                    abi_info=flags.abi_info,
                 )
             )
 
@@ -842,6 +851,11 @@ class PreLowerStripPhis(FunctionPass):
             newblk.body = [stmt for stmt in block.body if stmt not in phis]
 
             # insert exporters
+            # Get the block's terminator location for use when the variable
+            # was not assigned in this block (e.g., in continue/break paths).
+            term_loc = (
+                block.terminator.loc if block.is_terminated else block.loc
+            )
             for target, rhs in exporters[label]:
                 # If RHS is undefined
                 if rhs is ir.UNDEFINED:
@@ -849,7 +863,6 @@ class PreLowerStripPhis(FunctionPass):
                     # will eventually materialize as the prologue.
                     rhs = ir.Expr.null(loc=func_ir.loc)
 
-                assign = ir.Assign(target=target, value=rhs, loc=rhs.loc)
                 # Insert at the earliest possible location; i.e. after the
                 # last assignment to rhs
                 assignments = [
@@ -858,9 +871,16 @@ class PreLowerStripPhis(FunctionPass):
                     if stmt.target == rhs
                 ]
                 if assignments:
+                    # Variable was assigned in this block; use RHS location
+                    # to keep the location info at the assignment site.
+                    assign = ir.Assign(target=target, value=rhs, loc=rhs.loc)
                     last_assignment = assignments[-1]
                     newblk.insert_after(assign, last_assignment)
                 else:
+                    # Variable was NOT assigned in this block (just passed
+                    # through, e.g., in continue/break blocks). Use the
+                    # terminator location to preserve location info.
+                    assign = ir.Assign(target=target, value=rhs, loc=term_loc)
                     newblk.prepend(assign)
 
         func_ir.blocks = newblocks
