@@ -47,7 +47,7 @@ def get_itemsize(context, list_type):
     return context.get_abi_sizeof(llty)
 
 
-class _ListPayloadMixin(object):
+class _ListPayloadMixin:
     @property
     def size(self):
         return self._payload.size
@@ -117,7 +117,7 @@ class _ListPayloadMixin(object):
         Raise an error if the index is out of bounds.
         """
         with self._builder.if_then(self.is_out_of_bounds(idx), likely=False):
-            self._context.call_conv.return_user_exc(
+            self._context.fndesc.call_conv.return_user_exc(
                 self._builder, IndexError, (msg,)
             )
 
@@ -347,7 +347,7 @@ class ListInstance(_ListPayloadMixin):
         """
         ok, self = cls.allocate_ex(context, builder, list_type, nitems)
         with builder.if_then(builder.not_(ok), likely=False):
-            context.call_conv.return_user_exc(
+            context.fndesc.call_conv.return_user_exc(
                 builder, MemoryError, ("cannot allocate list",)
             )
         return self
@@ -384,7 +384,7 @@ class ListInstance(_ListPayloadMixin):
                 ir.Constant(intp_t, payload_size),
             )
             with builder.if_then(ovf, likely=False):
-                context.call_conv.return_user_exc(
+                context.fndesc.call_conv.return_user_exc(
                     builder, MemoryError, ("cannot resize list",)
                 )
 
@@ -654,7 +654,9 @@ def setitem_list(context, builder, sig, args):  # noqa: F811
         with otherwise:
             with builder.if_then(builder.icmp_signed("!=", size_delta, zero)):
                 msg = "cannot resize extended list slice with step != 1"
-                context.call_conv.return_user_exc(builder, ValueError, (msg,))
+                context.fndesc.call_conv.return_user_exc(
+                    builder, ValueError, (msg,)
+                )
 
             with cgutils.for_range_slice_generic(
                 builder, slice.start, slice.stop, slice.step
@@ -693,7 +695,9 @@ def delitem_list(context, builder, sig, args):
         builder.icmp_signed("!=", slice.step, one), likely=False
     ):
         msg = "unsupported del list[start:stop:step] with step != 1"
-        context.call_conv.return_user_exc(builder, NotImplementedError, (msg,))
+        context.fndesc.call_conv.return_user_exc(
+            builder, NotImplementedError, (msg,)
+        )
 
     # Compute the real stop, e.g. for dest[2:0]
     start = slice.start
